cleanup_region_file_artifacts

Function cleanup_region_file_artifacts 

pub(crate) async fn cleanup_region_file_artifacts(
    region_id: RegionId,
    table_dir: &str,
    intermediate_manager: &IntermediateManager,
    cache_manager: &CacheManagerRef,
)
Cleans files and caches that are produced at runtime but are not part of the primary region directory deletion.